# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: name_registry_event.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19name_registry_event.proto\"\xc9\x01\n\x11NameRegistryEvent\x12\x14\n\x0c\x62lock_number\x18\x01 \x01(\r\x12\x12\n\nblock_hash\x18\x02 \x01(\x0c\x12\x18\n\x10transaction_hash\x18\x03 \x01(\x0c\x12\x11\n\tlog_index\x18\x04 \x01(\r\x12\r\n\x05\x66name\x18\x05 \x01(\x0c\x12\x0c\n\x04\x66rom\x18\x06 \x01(\x0c\x12\n\n\x02to\x18\x07 \x01(\x0c\x12$\n\x04type\x18\x08 \x01(\x0e\x32\x16.NameRegistryEventType\x12\x0e\n\x06\x65xpiry\x18\t \x01(\r*\x85\x01\n\x15NameRegistryEventType\x12!\n\x1dNAME_REGISTRY_EVENT_TYPE_NONE\x10\x00\x12%\n!NAME_REGISTRY_EVENT_TYPE_TRANSFER\x10\x01\x12\"\n\x1eNAME_REGISTRY_EVENT_TYPE_RENEW\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'name_registry_event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NAMEREGISTRYEVENTTYPE']._serialized_start=234
  _globals['_NAMEREGISTRYEVENTTYPE']._serialized_end=367
  _globals['_NAMEREGISTRYEVENT']._serialized_start=30
  _globals['_NAMEREGISTRYEVENT']._serialized_end=231
# @@protoc_insertion_point(module_scope)
