import farglot.__farcaster.generated.message_pb2 as _message_pb2
import farglot.__farcaster.generated.id_registry_event_pb2 as _id_registry_event_pb2
import farglot.__farcaster.generated.name_registry_event_pb2 as _name_registry_event_pb2
import farglot.__farcaster.generated.hub_event_pb2 as _hub_event_pb2
import farglot.__farcaster.generated.request_response_pb2 as _request_response_pb2
import farglot.__farcaster.generated.username_proof_pb2 as _username_proof_pb2
import farglot.__farcaster.generated.onchain_event_pb2 as _onchain_event_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
