# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gossip.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import farcaster.generated.message_pb2 as message__pb2
import farcaster.generated.id_registry_event_pb2 as id__registry__event__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0cgossip.proto\x1a\rmessage.proto\x1a\x17id_registry_event.proto"T\n\x11GossipAddressInfo\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0e\n\x06\x66\x61mily\x18\x02 \x01(\r\x12\x0c\n\x04port\x18\x03 \x01(\r\x12\x10\n\x08\x64ns_name\x18\x04 \x01(\t"\xdf\x01\n\x12\x43ontactInfoContent\x12*\n\x0egossip_address\x18\x01 \x01(\x0b\x32\x12.GossipAddressInfo\x12\'\n\x0brpc_address\x18\x02 \x01(\x0b\x32\x12.GossipAddressInfo\x12\x17\n\x0f\x65xcluded_hashes\x18\x03 \x03(\t\x12\r\n\x05\x63ount\x18\x04 \x01(\r\x12\x13\n\x0bhub_version\x18\x05 \x01(\t\x12"\n\x07network\x18\x06 \x01(\x0e\x32\x11.FarcasterNetwork\x12\x13\n\x0b\x61pp_version\x18\x07 \x01(\t"F\n\x0fPingMessageBody\x12\x1b\n\x13ping_origin_peer_id\x18\x01 \x01(\x0c\x12\x16\n\x0eping_timestamp\x18\x02 \x01(\x04"x\n\x0e\x41\x63kMessageBody\x12\x1b\n\x13ping_origin_peer_id\x18\x01 \x01(\x0c\x12\x1a\n\x12\x61\x63k_origin_peer_id\x18\x02 \x01(\x0c\x12\x16\n\x0eping_timestamp\x18\x03 \x01(\x04\x12\x15\n\rack_timestamp\x18\x04 \x01(\x04"q\n\x15NetworkLatencyMessage\x12(\n\x0cping_message\x18\x02 \x01(\x0b\x32\x10.PingMessageBodyH\x00\x12&\n\x0b\x61\x63k_message\x18\x03 \x01(\x0b\x32\x0f.AckMessageBodyH\x00\x42\x06\n\x04\x62ody"\x98\x02\n\rGossipMessage\x12\x1b\n\x07message\x18\x01 \x01(\x0b\x32\x08.MessageH\x00\x12-\n\x11id_registry_event\x18\x02 \x01(\x0b\x32\x10.IdRegistryEventH\x00\x12\x33\n\x14\x63ontact_info_content\x18\x03 \x01(\x0b\x32\x13.ContactInfoContentH\x00\x12\x39\n\x17network_latency_message\x18\x07 \x01(\x0b\x32\x16.NetworkLatencyMessageH\x00\x12\x0e\n\x06topics\x18\x04 \x03(\t\x12\x0f\n\x07peer_id\x18\x05 \x01(\x0c\x12\x1f\n\x07version\x18\x06 \x01(\x0e\x32\x0e.GossipVersionB\t\n\x07\x63ontent*?\n\rGossipVersion\x12\x15\n\x11GOSSIP_VERSION_V1\x10\x00\x12\x17\n\x13GOSSIP_VERSION_V1_1\x10\x01\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "gossip_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_GOSSIPVERSION"]._serialized_start = 960
    _globals["_GOSSIPVERSION"]._serialized_end = 1023
    _globals["_GOSSIPADDRESSINFO"]._serialized_start = 56
    _globals["_GOSSIPADDRESSINFO"]._serialized_end = 140
    _globals["_CONTACTINFOCONTENT"]._serialized_start = 143
    _globals["_CONTACTINFOCONTENT"]._serialized_end = 366
    _globals["_PINGMESSAGEBODY"]._serialized_start = 368
    _globals["_PINGMESSAGEBODY"]._serialized_end = 438
    _globals["_ACKMESSAGEBODY"]._serialized_start = 440
    _globals["_ACKMESSAGEBODY"]._serialized_end = 560
    _globals["_NETWORKLATENCYMESSAGE"]._serialized_start = 562
    _globals["_NETWORKLATENCYMESSAGE"]._serialized_end = 675
    _globals["_GOSSIPMESSAGE"]._serialized_start = 678
    _globals["_GOSSIPMESSAGE"]._serialized_end = 958
# @@protoc_insertion_point(module_scope)
