# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hub_event.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import farglot.__farcaster.generated.message_pb2 as message__pb2
import farglot.__farcaster.generated.id_registry_event_pb2 as id__registry__event__pb2
import farglot.__farcaster.generated.name_registry_event_pb2 as name__registry__event__pb2
import farglot.__farcaster.generated.onchain_event_pb2 as onchain__event__pb2
import farglot.__farcaster.generated.username_proof_pb2 as username__proof__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0fhub_event.proto\x1a\rmessage.proto\x1a\x17id_registry_event.proto\x1a\x19name_registry_event.proto\x1a\x13onchain_event.proto\x1a\x14username_proof.proto"Q\n\x10MergeMessageBody\x12\x19\n\x07message\x18\x01 \x01(\x0b\x32\x08.Message\x12"\n\x10\x64\x65leted_messages\x18\x02 \x03(\x0b\x32\x08.Message"-\n\x10PruneMessageBody\x12\x19\n\x07message\x18\x01 \x01(\x0b\x32\x08.Message".\n\x11RevokeMessageBody\x12\x19\n\x07message\x18\x01 \x01(\x0b\x32\x08.Message"G\n\x18MergeIdRegistryEventBody\x12+\n\x11id_registry_event\x18\x01 \x01(\x0b\x32\x10.IdRegistryEvent"M\n\x1aMergeNameRegistryEventBody\x12/\n\x13name_registry_event\x18\x01 \x01(\x0b\x32\x12.NameRegistryEvent">\n\x15MergeOnChainEventBody\x12%\n\x0eon_chain_event\x18\x01 \x01(\x0b\x32\r.OnChainEvent"\xcc\x01\n\x16MergeUserNameProofBody\x12&\n\x0eusername_proof\x18\x01 \x01(\x0b\x32\x0e.UserNameProof\x12.\n\x16\x64\x65leted_username_proof\x18\x02 \x01(\x0b\x32\x0e.UserNameProof\x12(\n\x16username_proof_message\x18\x03 \x01(\x0b\x32\x08.Message\x12\x30\n\x1e\x64\x65leted_username_proof_message\x18\x04 \x01(\x0b\x32\x08.Message"\xd5\x03\n\x08HubEvent\x12\x1b\n\x04type\x18\x01 \x01(\x0e\x32\r.HubEventType\x12\n\n\x02id\x18\x02 \x01(\x04\x12/\n\x12merge_message_body\x18\x03 \x01(\x0b\x32\x11.MergeMessageBodyH\x00\x12/\n\x12prune_message_body\x18\x04 \x01(\x0b\x32\x11.PruneMessageBodyH\x00\x12\x31\n\x13revoke_message_body\x18\x05 \x01(\x0b\x32\x12.RevokeMessageBodyH\x00\x12\x41\n\x1cmerge_id_registry_event_body\x18\x06 \x01(\x0b\x32\x19.MergeIdRegistryEventBodyH\x00\x12\x45\n\x1emerge_name_registry_event_body\x18\x07 \x01(\x0b\x32\x1b.MergeNameRegistryEventBodyH\x00\x12<\n\x19merge_username_proof_body\x18\x08 \x01(\x0b\x32\x17.MergeUserNameProofBodyH\x00\x12;\n\x19merge_on_chain_event_body\x18\x0b \x01(\x0b\x32\x16.MergeOnChainEventBodyH\x00\x42\x06\n\x04\x62ody*\xba\x02\n\x0cHubEventType\x12\x17\n\x13HUB_EVENT_TYPE_NONE\x10\x00\x12 \n\x1cHUB_EVENT_TYPE_MERGE_MESSAGE\x10\x01\x12 \n\x1cHUB_EVENT_TYPE_PRUNE_MESSAGE\x10\x02\x12!\n\x1dHUB_EVENT_TYPE_REVOKE_MESSAGE\x10\x03\x12*\n&HUB_EVENT_TYPE_MERGE_ID_REGISTRY_EVENT\x10\x04\x12,\n(HUB_EVENT_TYPE_MERGE_NAME_REGISTRY_EVENT\x10\x05\x12\'\n#HUB_EVENT_TYPE_MERGE_USERNAME_PROOF\x10\x06\x12\'\n#HUB_EVENT_TYPE_MERGE_ON_CHAIN_EVENT\x10\tb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "hub_event_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_HUBEVENTTYPE"]._serialized_start = 1203
    _globals["_HUBEVENTTYPE"]._serialized_end = 1517
    _globals["_MERGEMESSAGEBODY"]._serialized_start = 129
    _globals["_MERGEMESSAGEBODY"]._serialized_end = 210
    _globals["_PRUNEMESSAGEBODY"]._serialized_start = 212
    _globals["_PRUNEMESSAGEBODY"]._serialized_end = 257
    _globals["_REVOKEMESSAGEBODY"]._serialized_start = 259
    _globals["_REVOKEMESSAGEBODY"]._serialized_end = 305
    _globals["_MERGEIDREGISTRYEVENTBODY"]._serialized_start = 307
    _globals["_MERGEIDREGISTRYEVENTBODY"]._serialized_end = 378
    _globals["_MERGENAMEREGISTRYEVENTBODY"]._serialized_start = 380
    _globals["_MERGENAMEREGISTRYEVENTBODY"]._serialized_end = 457
    _globals["_MERGEONCHAINEVENTBODY"]._serialized_start = 459
    _globals["_MERGEONCHAINEVENTBODY"]._serialized_end = 521
    _globals["_MERGEUSERNAMEPROOFBODY"]._serialized_start = 524
    _globals["_MERGEUSERNAMEPROOFBODY"]._serialized_end = 728
    _globals["_HUBEVENT"]._serialized_start = 731
    _globals["_HUBEVENT"]._serialized_end = 1200
# @@protoc_insertion_point(module_scope)
