# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: request_response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import farglot.__farcaster.generated.message_pb2 as message__pb2
import farglot.__farcaster.generated.onchain_event_pb2 as onchain__event__pb2
import farglot.__farcaster.generated.hub_event_pb2 as hub__event__pb2
import farglot.__farcaster.generated.username_proof_pb2 as username__proof__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16request_response.proto\x1a\rmessage.proto\x1a\x13onchain_event.proto\x1a\x0fhub_event.proto\x1a\x14username_proof.proto"\x07\n\x05\x45mpty"X\n\x10SubscribeRequest\x12"\n\x0b\x65vent_types\x18\x01 \x03(\x0e\x32\r.HubEventType\x12\x14\n\x07\x66rom_id\x18\x02 \x01(\x04H\x00\x88\x01\x01\x42\n\n\x08_from_id"\x1a\n\x0c\x45ventRequest\x12\n\n\x02id\x18\x01 \x01(\x04""\n\x0eHubInfoRequest\x12\x10\n\x08\x64\x62_stats\x18\x01 \x01(\x08"w\n\x0fHubInfoResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x12\n\nis_syncing\x18\x02 \x01(\x08\x12\x10\n\x08nickname\x18\x03 \x01(\t\x12\x11\n\troot_hash\x18\x04 \x01(\t\x12\x1a\n\x08\x64\x62_stats\x18\x05 \x01(\x0b\x32\x08.DbStats"Q\n\x07\x44\x62Stats\x12\x14\n\x0cnum_messages\x18\x01 \x01(\x04\x12\x16\n\x0enum_fid_events\x18\x02 \x01(\x04\x12\x18\n\x10num_fname_events\x18\x03 \x01(\x04"3\n\x11SyncStatusRequest\x12\x13\n\x06peerId\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\t\n\x07_peerId"b\n\x12SyncStatusResponse\x12\x12\n\nis_syncing\x18\x01 \x01(\x08\x12 \n\x0bsync_status\x18\x02 \x03(\x0b\x32\x0b.SyncStatus\x12\x16\n\x0e\x65ngine_started\x18\x03 \x01(\x08"\xb9\x01\n\nSyncStatus\x12\x0e\n\x06peerId\x18\x01 \x01(\t\x12\x0e\n\x06inSync\x18\x02 \x01(\t\x12\x12\n\nshouldSync\x18\x03 \x01(\x08\x12\x18\n\x10\x64ivergencePrefix\x18\x04 \x01(\t\x12\x1c\n\x14\x64ivergenceSecondsAgo\x18\x05 \x01(\x05\x12\x15\n\rtheirMessages\x18\x06 \x01(\x04\x12\x13\n\x0bourMessages\x18\x07 \x01(\x04\x12\x13\n\x0blastBadSync\x18\x08 \x01(\x03"{\n\x18TrieNodeMetadataResponse\x12\x0e\n\x06prefix\x18\x01 \x01(\x0c\x12\x14\n\x0cnum_messages\x18\x02 \x01(\x04\x12\x0c\n\x04hash\x18\x03 \x01(\t\x12+\n\x08\x63hildren\x18\x04 \x03(\x0b\x32\x19.TrieNodeMetadataResponse"l\n\x18TrieNodeSnapshotResponse\x12\x0e\n\x06prefix\x18\x01 \x01(\x0c\x12\x17\n\x0f\x65xcluded_hashes\x18\x02 \x03(\t\x12\x14\n\x0cnum_messages\x18\x03 \x01(\x04\x12\x11\n\troot_hash\x18\x04 \x01(\t" \n\x0eTrieNodePrefix\x12\x0e\n\x06prefix\x18\x01 \x01(\x0c"\x1b\n\x07SyncIds\x12\x10\n\x08sync_ids\x18\x01 \x03(\x0c"\x89\x01\n\nFidRequest\x12\x0b\n\x03\x66id\x18\x01 \x01(\x04\x12\x16\n\tpage_size\x18\x02 \x01(\rH\x00\x88\x01\x01\x12\x17\n\npage_token\x18\x03 \x01(\x0cH\x01\x88\x01\x01\x12\x14\n\x07reverse\x18\x04 \x01(\x08H\x02\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\n\n\x08_reverse"}\n\x0b\x46idsRequest\x12\x16\n\tpage_size\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x17\n\npage_token\x18\x02 \x01(\x0cH\x01\x88\x01\x01\x12\x14\n\x07reverse\x18\x03 \x01(\x08H\x02\x88\x01\x01\x42\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\n\n\x08_reverse"N\n\x0c\x46idsResponse\x12\x0c\n\x04\x66ids\x18\x01 \x03(\x04\x12\x1c\n\x0fnext_page_token\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x42\x12\n\x10_next_page_token"`\n\x10MessagesResponse\x12\x1a\n\x08messages\x18\x01 \x03(\x0b\x32\x08.Message\x12\x1c\n\x0fnext_page_token\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x42\x12\n\x10_next_page_token"\xc9\x01\n\x14\x43\x61stsByParentRequest\x12!\n\x0eparent_cast_id\x18\x01 \x01(\x0b\x32\x07.CastIdH\x00\x12\x14\n\nparent_url\x18\x05 \x01(\tH\x00\x12\x16\n\tpage_size\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x17\n\npage_token\x18\x03 \x01(\x0cH\x02\x88\x01\x01\x12\x14\n\x07reverse\x18\x04 \x01(\x08H\x03\x88\x01\x01\x42\x08\n\x06parentB\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\n\n\x08_reverse"\x87\x01\n\x0fReactionRequest\x12\x0b\n\x03\x66id\x18\x01 \x01(\x04\x12$\n\rreaction_type\x18\x02 \x01(\x0e\x32\r.ReactionType\x12!\n\x0etarget_cast_id\x18\x03 \x01(\x0b\x32\x07.CastIdH\x00\x12\x14\n\ntarget_url\x18\x04 \x01(\tH\x00\x42\x08\n\x06target"\xd1\x01\n\x15ReactionsByFidRequest\x12\x0b\n\x03\x66id\x18\x01 \x01(\x04\x12)\n\rreaction_type\x18\x02 \x01(\x0e\x32\r.ReactionTypeH\x00\x88\x01\x01\x12\x16\n\tpage_size\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x17\n\npage_token\x18\x04 \x01(\x0cH\x02\x88\x01\x01\x12\x14\n\x07reverse\x18\x05 \x01(\x08H\x03\x88\x01\x01\x42\x10\n\x0e_reaction_typeB\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\n\n\x08_reverse"\x8a\x02\n\x18ReactionsByTargetRequest\x12!\n\x0etarget_cast_id\x18\x01 \x01(\x0b\x32\x07.CastIdH\x00\x12\x14\n\ntarget_url\x18\x06 \x01(\tH\x00\x12)\n\rreaction_type\x18\x02 \x01(\x0e\x32\r.ReactionTypeH\x01\x88\x01\x01\x12\x16\n\tpage_size\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x17\n\npage_token\x18\x04 \x01(\x0cH\x03\x88\x01\x01\x12\x14\n\x07reverse\x18\x05 \x01(\x08H\x04\x88\x01\x01\x42\x08\n\x06targetB\x10\n\x0e_reaction_typeB\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\n\n\x08_reverse"E\n\x0fUserDataRequest\x12\x0b\n\x03\x66id\x18\x01 \x01(\x04\x12%\n\x0euser_data_type\x18\x02 \x01(\x0e\x32\r.UserDataType"(\n\x18NameRegistryEventRequest\x12\x0c\n\x04name\x18\x01 \x01(\x0c"(\n\x19RentRegistryEventsRequest\x12\x0b\n\x03\x66id\x18\x01 \x01(\x04"I\n\x13OnChainEventRequest\x12\x0b\n\x03\x66id\x18\x01 \x01(\x04\x12%\n\nevent_type\x18\x02 \x01(\x0e\x32\x11.OnChainEventType"5\n\x14OnChainEventResponse\x12\x1d\n\x06\x65vents\x18\x01 \x03(\x0b\x32\r.OnChainEvent"6\n\x15StorageLimitsResponse\x12\x1d\n\x06limits\x18\x01 \x03(\x0b\x32\r.StorageLimit"=\n\x0cStorageLimit\x12\x1e\n\nstore_type\x18\x01 \x01(\x0e\x32\n.StoreType\x12\r\n\x05limit\x18\x02 \x01(\x04"$\n\x14UsernameProofRequest\x12\x0c\n\x04name\x18\x01 \x01(\x0c"8\n\x16UsernameProofsResponse\x12\x1e\n\x06proofs\x18\x01 \x03(\x0b\x32\x0e.UserNameProof"3\n\x13VerificationRequest\x12\x0b\n\x03\x66id\x18\x01 \x01(\x04\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0c",\n\rSignerRequest\x12\x0b\n\x03\x66id\x18\x01 \x01(\x04\x12\x0e\n\x06signer\x18\x02 \x01(\x0c"M\n\x0bLinkRequest\x12\x0b\n\x03\x66id\x18\x01 \x01(\x04\x12\x11\n\tlink_type\x18\x02 \x01(\t\x12\x14\n\ntarget_fid\x18\x03 \x01(\x04H\x00\x42\x08\n\x06target"\xb6\x01\n\x11LinksByFidRequest\x12\x0b\n\x03\x66id\x18\x01 \x01(\x04\x12\x16\n\tlink_type\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tpage_size\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x17\n\npage_token\x18\x04 \x01(\x0cH\x02\x88\x01\x01\x12\x14\n\x07reverse\x18\x05 \x01(\x08H\x03\x88\x01\x01\x42\x0c\n\n_link_typeB\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\n\n\x08_reverse"\xcc\x01\n\x14LinksByTargetRequest\x12\x14\n\ntarget_fid\x18\x01 \x01(\x04H\x00\x12\x16\n\tlink_type\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x16\n\tpage_size\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x17\n\npage_token\x18\x04 \x01(\x0cH\x03\x88\x01\x01\x12\x14\n\x07reverse\x18\x05 \x01(\x08H\x04\x88\x01\x01\x42\x08\n\x06targetB\x0c\n\n_link_typeB\x0c\n\n_page_sizeB\r\n\x0b_page_tokenB\n\n\x08_reverse"%\n\x16IdRegistryEventRequest\x12\x0b\n\x03\x66id\x18\x01 \x01(\x04"2\n\x1fIdRegistryEventByAddressRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c*\x9e\x01\n\tStoreType\x12\x13\n\x0fSTORE_TYPE_NONE\x10\x00\x12\x14\n\x10STORE_TYPE_CASTS\x10\x01\x12\x14\n\x10STORE_TYPE_LINKS\x10\x02\x12\x18\n\x14STORE_TYPE_REACTIONS\x10\x03\x12\x18\n\x14STORE_TYPE_USER_DATA\x10\x04\x12\x1c\n\x18STORE_TYPE_VERIFICATIONS\x10\x05\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "request_response_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_STORETYPE"]._serialized_start = 3537
    _globals["_STORETYPE"]._serialized_end = 3695
    _globals["_EMPTY"]._serialized_start = 101
    _globals["_EMPTY"]._serialized_end = 108
    _globals["_SUBSCRIBEREQUEST"]._serialized_start = 110
    _globals["_SUBSCRIBEREQUEST"]._serialized_end = 198
    _globals["_EVENTREQUEST"]._serialized_start = 200
    _globals["_EVENTREQUEST"]._serialized_end = 226
    _globals["_HUBINFOREQUEST"]._serialized_start = 228
    _globals["_HUBINFOREQUEST"]._serialized_end = 262
    _globals["_HUBINFORESPONSE"]._serialized_start = 264
    _globals["_HUBINFORESPONSE"]._serialized_end = 383
    _globals["_DBSTATS"]._serialized_start = 385
    _globals["_DBSTATS"]._serialized_end = 466
    _globals["_SYNCSTATUSREQUEST"]._serialized_start = 468
    _globals["_SYNCSTATUSREQUEST"]._serialized_end = 519
    _globals["_SYNCSTATUSRESPONSE"]._serialized_start = 521
    _globals["_SYNCSTATUSRESPONSE"]._serialized_end = 619
    _globals["_SYNCSTATUS"]._serialized_start = 622
    _globals["_SYNCSTATUS"]._serialized_end = 807
    _globals["_TRIENODEMETADATARESPONSE"]._serialized_start = 809
    _globals["_TRIENODEMETADATARESPONSE"]._serialized_end = 932
    _globals["_TRIENODESNAPSHOTRESPONSE"]._serialized_start = 934
    _globals["_TRIENODESNAPSHOTRESPONSE"]._serialized_end = 1042
    _globals["_TRIENODEPREFIX"]._serialized_start = 1044
    _globals["_TRIENODEPREFIX"]._serialized_end = 1076
    _globals["_SYNCIDS"]._serialized_start = 1078
    _globals["_SYNCIDS"]._serialized_end = 1105
    _globals["_FIDREQUEST"]._serialized_start = 1108
    _globals["_FIDREQUEST"]._serialized_end = 1245
    _globals["_FIDSREQUEST"]._serialized_start = 1247
    _globals["_FIDSREQUEST"]._serialized_end = 1372
    _globals["_FIDSRESPONSE"]._serialized_start = 1374
    _globals["_FIDSRESPONSE"]._serialized_end = 1452
    _globals["_MESSAGESRESPONSE"]._serialized_start = 1454
    _globals["_MESSAGESRESPONSE"]._serialized_end = 1550
    _globals["_CASTSBYPARENTREQUEST"]._serialized_start = 1553
    _globals["_CASTSBYPARENTREQUEST"]._serialized_end = 1754
    _globals["_REACTIONREQUEST"]._serialized_start = 1757
    _globals["_REACTIONREQUEST"]._serialized_end = 1892
    _globals["_REACTIONSBYFIDREQUEST"]._serialized_start = 1895
    _globals["_REACTIONSBYFIDREQUEST"]._serialized_end = 2104
    _globals["_REACTIONSBYTARGETREQUEST"]._serialized_start = 2107
    _globals["_REACTIONSBYTARGETREQUEST"]._serialized_end = 2373
    _globals["_USERDATAREQUEST"]._serialized_start = 2375
    _globals["_USERDATAREQUEST"]._serialized_end = 2444
    _globals["_NAMEREGISTRYEVENTREQUEST"]._serialized_start = 2446
    _globals["_NAMEREGISTRYEVENTREQUEST"]._serialized_end = 2486
    _globals["_RENTREGISTRYEVENTSREQUEST"]._serialized_start = 2488
    _globals["_RENTREGISTRYEVENTSREQUEST"]._serialized_end = 2528
    _globals["_ONCHAINEVENTREQUEST"]._serialized_start = 2530
    _globals["_ONCHAINEVENTREQUEST"]._serialized_end = 2603
    _globals["_ONCHAINEVENTRESPONSE"]._serialized_start = 2605
    _globals["_ONCHAINEVENTRESPONSE"]._serialized_end = 2658
    _globals["_STORAGELIMITSRESPONSE"]._serialized_start = 2660
    _globals["_STORAGELIMITSRESPONSE"]._serialized_end = 2714
    _globals["_STORAGELIMIT"]._serialized_start = 2716
    _globals["_STORAGELIMIT"]._serialized_end = 2777
    _globals["_USERNAMEPROOFREQUEST"]._serialized_start = 2779
    _globals["_USERNAMEPROOFREQUEST"]._serialized_end = 2815
    _globals["_USERNAMEPROOFSRESPONSE"]._serialized_start = 2817
    _globals["_USERNAMEPROOFSRESPONSE"]._serialized_end = 2873
    _globals["_VERIFICATIONREQUEST"]._serialized_start = 2875
    _globals["_VERIFICATIONREQUEST"]._serialized_end = 2926
    _globals["_SIGNERREQUEST"]._serialized_start = 2928
    _globals["_SIGNERREQUEST"]._serialized_end = 2972
    _globals["_LINKREQUEST"]._serialized_start = 2974
    _globals["_LINKREQUEST"]._serialized_end = 3051
    _globals["_LINKSBYFIDREQUEST"]._serialized_start = 3054
    _globals["_LINKSBYFIDREQUEST"]._serialized_end = 3236
    _globals["_LINKSBYTARGETREQUEST"]._serialized_start = 3239
    _globals["_LINKSBYTARGETREQUEST"]._serialized_end = 3443
    _globals["_IDREGISTRYEVENTREQUEST"]._serialized_start = 3445
    _globals["_IDREGISTRYEVENTREQUEST"]._serialized_end = 3482
    _globals["_IDREGISTRYEVENTBYADDRESSREQUEST"]._serialized_start = 3484
    _globals["_IDREGISTRYEVENTBYADDRESSREQUEST"]._serialized_end = 3534
# @@protoc_insertion_point(module_scope)
