# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import farglot.__farcaster.generated.message_pb2 as message__pb2
import farglot.__farcaster.generated.id_registry_event_pb2 as id__registry__event__pb2
import farglot.__farcaster.generated.name_registry_event_pb2 as name__registry__event__pb2
import farglot.__farcaster.generated.hub_event_pb2 as hub__event__pb2
import farglot.__farcaster.generated.request_response_pb2 as request__response__pb2
import farglot.__farcaster.generated.username_proof_pb2 as username__proof__pb2
import farglot.__farcaster.generated.onchain_event_pb2 as onchain__event__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b"\n\trpc.proto\x1a\rmessage.proto\x1a\x17id_registry_event.proto\x1a\x19name_registry_event.proto\x1a\x0fhub_event.proto\x1a\x16request_response.proto\x1a\x14username_proof.proto\x1a\x13onchain_event.proto2\x86\x12\n\nHubService\x12#\n\rSubmitMessage\x12\x08.Message\x1a\x08.Message\x12+\n\tSubscribe\x12\x11.SubscribeRequest\x1a\t.HubEvent0\x01\x12$\n\x08GetEvent\x12\r.EventRequest\x1a\t.HubEvent\x12\x1c\n\x07GetCast\x12\x07.CastId\x1a\x08.Message\x12/\n\rGetCastsByFid\x12\x0b.FidRequest\x1a\x11.MessagesResponse\x12<\n\x10GetCastsByParent\x12\x15.CastsByParentRequest\x1a\x11.MessagesResponse\x12\x33\n\x11GetCastsByMention\x12\x0b.FidRequest\x1a\x11.MessagesResponse\x12)\n\x0bGetReaction\x12\x10.ReactionRequest\x1a\x08.Message\x12>\n\x11GetReactionsByFid\x12\x16.ReactionsByFidRequest\x1a\x11.MessagesResponse\x12\x42\n\x12GetReactionsByCast\x12\x19.ReactionsByTargetRequest\x1a\x11.MessagesResponse\x12\x44\n\x14GetReactionsByTarget\x12\x19.ReactionsByTargetRequest\x1a\x11.MessagesResponse\x12)\n\x0bGetUserData\x12\x10.UserDataRequest\x1a\x08.Message\x12\x32\n\x10GetUserDataByFid\x12\x0b.FidRequest\x1a\x11.MessagesResponse\x12\x45\n\x14GetNameRegistryEvent\x12\x19.NameRegistryEventRequest\x1a\x12.NameRegistryEvent\x12?\n\x10GetOnChainEvents\x12\x14.OnChainEventRequest\x1a\x15.OnChainEventResponse\x12\x43\n\x1cGetCurrentStorageLimitsByFid\x12\x0b.FidRequest\x1a\x16.StorageLimitsResponse\x12\x39\n\x10GetUsernameProof\x12\x15.UsernameProofRequest\x1a\x0e.UserNameProof\x12>\n\x16GetUserNameProofsByFid\x12\x0b.FidRequest\x1a\x17.UsernameProofsResponse\x12\x31\n\x0fGetVerification\x12\x14.VerificationRequest\x1a\x08.Message\x12\x37\n\x15GetVerificationsByFid\x12\x0b.FidRequest\x1a\x11.MessagesResponse\x12%\n\tGetSigner\x12\x0e.SignerRequest\x1a\x08.Message\x12\x31\n\x10GetOnChainSigner\x12\x0e.SignerRequest\x1a\r.OnChainEvent\x12\x31\n\x0fGetSignersByFid\x12\x0b.FidRequest\x1a\x11.MessagesResponse\x12?\n\x12GetIdRegistryEvent\x12\x17.IdRegistryEventRequest\x1a\x10.IdRegistryEvent\x12Q\n\x1bGetIdRegistryEventByAddress\x12 .IdRegistryEventByAddressRequest\x1a\x10.IdRegistryEvent\x12&\n\x07GetFids\x12\x0c.FidsRequest\x1a\r.FidsResponse\x12!\n\x07GetLink\x12\x0c.LinkRequest\x1a\x08.Message\x12\x36\n\rGetLinksByFid\x12\x12.LinksByFidRequest\x1a\x11.MessagesResponse\x12<\n\x10GetLinksByTarget\x12\x15.LinksByTargetRequest\x1a\x11.MessagesResponse\x12\x39\n\x17GetAllCastMessagesByFid\x12\x0b.FidRequest\x1a\x11.MessagesResponse\x12=\n\x1bGetAllReactionMessagesByFid\x12\x0b.FidRequest\x1a\x11.MessagesResponse\x12\x41\n\x1fGetAllVerificationMessagesByFid\x12\x0b.FidRequest\x1a\x11.MessagesResponse\x12;\n\x19GetAllSignerMessagesByFid\x12\x0b.FidRequest\x1a\x11.MessagesResponse\x12=\n\x1bGetAllUserDataMessagesByFid\x12\x0b.FidRequest\x1a\x11.MessagesResponse\x12\x39\n\x17GetAllLinkMessagesByFid\x12\x0b.FidRequest\x1a\x11.MessagesResponse\x12,\n\x07GetInfo\x12\x0f.HubInfoRequest\x1a\x10.HubInfoResponse\x12\x38\n\rGetSyncStatus\x12\x12.SyncStatusRequest\x1a\x13.SyncStatusResponse\x12\x32\n\x15GetAllSyncIdsByPrefix\x12\x0f.TrieNodePrefix\x1a\x08.SyncIds\x12\x36\n\x17GetAllMessagesBySyncIds\x12\x08.SyncIds\x1a\x11.MessagesResponse\x12\x45\n\x17GetSyncMetadataByPrefix\x12\x0f.TrieNodePrefix\x1a\x19.TrieNodeMetadataResponse\x12\x45\n\x17GetSyncSnapshotByPrefix\x12\x0f.TrieNodePrefix\x1a\x19.TrieNodeSnapshotResponse2\x90\x02\n\x0c\x41\x64minService\x12!\n\x0fRebuildSyncTrie\x12\x06.Empty\x1a\x06.Empty\x12)\n\x17\x44\x65leteAllMessagesFromDb\x12\x06.Empty\x1a\x06.Empty\x12;\n\x15SubmitIdRegistryEvent\x12\x10.IdRegistryEvent\x1a\x10.IdRegistryEvent\x12\x41\n\x17SubmitNameRegistryEvent\x12\x12.NameRegistryEvent\x1a\x12.NameRegistryEvent\x12\x32\n\x12SubmitOnChainEvent\x12\r.OnChainEvent\x1a\r.OnChainEventb\x06proto3"
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "rpc_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_HUBSERVICE"]._serialized_start = 165
    _globals["_HUBSERVICE"]._serialized_end = 2475
    _globals["_ADMINSERVICE"]._serialized_start = 2478
    _globals["_ADMINSERVICE"]._serialized_end = 2750
# @@protoc_insertion_point(module_scope)
