# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: job.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tjob.proto\"?\n RevokeMessagesBySignerJobPayload\x12\x0b\n\x03\x66id\x18\x01 \x01(\r\x12\x0e\n\x06signer\x18\x02 \x01(\x0c\"8\n\'UpdateNameRegistryEventExpiryJobPayload\x12\r\n\x05\x66name\x18\x01 \x01(\x0c\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'job_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_REVOKEMESSAGESBYSIGNERJOBPAYLOAD']._serialized_start=13
  _globals['_REVOKEMESSAGESBYSIGNERJOBPAYLOAD']._serialized_end=76
  _globals['_UPDATENAMEREGISTRYEVENTEXPIRYJOBPAYLOAD']._serialized_start=78
  _globals['_UPDATENAMEREGISTRYEVENTEXPIRYJOBPAYLOAD']._serialized_end=134
# @@protoc_insertion_point(module_scope)
